@@ -5,12 +5,12 @@ use warnings;
 
 use Scalar::Util ();
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub import {
     no strict;
     if (@_ > 0) {
-        *{caller() . "::method"} = \&method;
+        *{caller() . '::method'} = \&method;
     }
 }
 
@@ -29,7 +29,7 @@ sub method {
         bless $o, $p;
         {
             no strict;
-            @{$p . "::ISA"}=($op);
+            @{$p . '::ISA'}=($op);
         }
     }
 
@@ -41,6 +41,7 @@ sub method {
 }
 
 1;
+
 __END__
 
 =head1 NAME
@@ -139,40 +140,13 @@ moment.
 
 =head1 AUTHOR
 
-Kang-min Liu E<lt>gugod@gugod.orgE<gt>
+Kang-min Liu
 
-=head1 SEE ALSO
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright (c) 2010, Kang-min Liu C<< <gugod@gugod.org> >>.
+=head1 LICENSE
 
 This is free software, licensed under:
 
     The MIT (X11) License
 
-=head1 DISCLAIMER OF WARRANTY
-
-BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
-FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
-OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
-PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
-EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
-WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
-ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
-YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
-NECESSARY SERVICING, REPAIR, OR CORRECTION.
-
-IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
-WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
-REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENSE, BE
-LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
-OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
-THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
-RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
-FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
-SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
-SUCH DAMAGES.
-
 =cut
 
